@@ -6,11 +6,13 @@
  *  Richard Hult <rhult@hem.passagen.se>
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2006  LUGFI
+ * Copyright (C) 2003,2006  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,22 +26,23 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
+
 #include <glib.h>
-#include "main.h"
+
+#include "oregano.h"
 #include "sheet-item.h"
-#include "item-data.h"
 #include "clipboard.h"
 
-struct _ClipboardData {
+struct _ClipboardData
+{
 	ItemData *item_data;
 	SheetItemClass *item_class;
 };
 
-void
-clipboard_empty (void)
+void clipboard_empty (void)
 {
 	GSList *list;
 	ClipboardData *cb_data;
@@ -58,8 +61,7 @@ clipboard_empty (void)
 	oregano.clipboard = NULL;
 }
 
-gboolean
-clipboard_is_empty (void)
+gboolean clipboard_is_empty (void)
 {
 	if (oregano.clipboard == NULL)
 		return TRUE;
@@ -67,8 +69,7 @@ clipboard_is_empty (void)
 	return g_slist_length (oregano.clipboard) > 0 ? FALSE : TRUE;
 }
 
-void
-clipboard_foreach (ClipBoardFunction callback, gpointer user_data)
+void clipboard_foreach (ClipBoardFunction callback, gpointer user_data)
 {
 	GSList *list;
 	ClipboardData *data;
@@ -82,8 +83,7 @@ clipboard_foreach (ClipBoardFunction callback, gpointer user_data)
 	}
 }
 
-void
-clipboard_add_object (GObject *item)
+void clipboard_add_object (GObject *item)
 {
 	ItemDataClass *id_class;
 	ItemData *item_data, *clone;
@@ -91,18 +91,14 @@ clipboard_add_object (GObject *item)
 
 	g_return_if_fail (item != NULL);
 
-	/* TODO: FIX sheet global access */
-	g_return_if_fail (IS_SHEET_ITEM (item));
-
 	item_data = sheet_item_get_data (SHEET_ITEM (item));
+	g_return_if_fail (item_data != NULL);
 
 	id_class = ITEM_DATA_CLASS (G_OBJECT_GET_CLASS (item_data));
 	if (id_class->clone == NULL)
 		return;
 
-	/*
-	 * Duplicate the data for the object and add to the clipboard.
-	 */
+	// Duplicate the data for the object and add to the clipboard.
 	clone = id_class->clone (item_data);
 
 	cb_data = g_new0 (ClipboardData, 1);
@@ -112,19 +108,16 @@ clipboard_add_object (GObject *item)
 	oregano.clipboard = g_slist_prepend (oregano.clipboard, cb_data);
 }
 
-GObject *
-clipboard_data_get_item_data (ClipboardData *data)
+GObject *clipboard_data_get_item_data (ClipboardData *data)
 {
 	g_return_val_if_fail (data != NULL, NULL);
 
 	return G_OBJECT (data->item_data);
 }
 
-GObjectClass *
-clipboard_data_get_item_class (ClipboardData *data)
+GObjectClass *clipboard_data_get_item_class (ClipboardData *data)
 {
 	g_return_val_if_fail (data != NULL, NULL);
 
 	return G_OBJECT_CLASS (data->item_class);
 }
-
