@@ -4,8 +4,12 @@
  *
  * Author:
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
  *
- * Copyright (C) 2003  Andres de Barbara
+ * Web page: https://ahoi.io/project/oregano
+ *
+ * Copyright (C) 2003-2008  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,14 +23,13 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "errors.h"
 
-GQuark
-oregano_error_quark (void) 
+GQuark oregano_error_quark (void)
 {
 	static GQuark err = 0;
 	if (!err) {
@@ -34,4 +37,3 @@ oregano_error_quark (void)
 	}
 	return err;
 }
-
