@@ -5,10 +5,12 @@
  * Authors:
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
- * Copyright (C) 2003,2006 LUGFI
+ * Copyright (C) 2003,2006 Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,30 +24,28 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "file-manager.h"
 
 FileType file_types[] = {
-	FILE_TYPE("oregano", "Oregano Schematic File", schematic_parse_xml_file, schematic_write_xml)
-};
-
-#define FILE_TYPES_COUNT (sizeof(file_types)/sizeof(FileType))
+    FILE_TYPE ("oregano", "Oregano Schematic File", schematic_parse_xml_file, schematic_write_xml)};
 
+#define FILE_TYPES_COUNT (sizeof(file_types) / sizeof(FileType))
 
 FileType *file_manager_get_handler (const gchar *fname)
 {
 	int i;
 	gchar *ext, *ptr;
-	FileType *ft = NULL; 
+	FileType *ft = NULL;
 
 	g_return_val_if_fail (fname != NULL, NULL);
 
 	ptr = ext = (gchar *)fname;
 
-	/* Search for file extension */
+	// Search for file extension
 	while (*ptr != '\0') {
 		if (*ptr == '.') {
 			ext = ptr + 1;
@@ -53,7 +53,7 @@ FileType *file_manager_get_handler (const gchar *fname)
 		ptr++;
 	}
 
-	for (i=0; i<FILE_TYPES_COUNT; i++)
+	for (i = 0; i < FILE_TYPES_COUNT; i++)
 		if (!strcmp (file_types[i].extension, ext)) {
 			ft = &file_types[i];
 			break;
@@ -61,4 +61,3 @@ FileType *file_manager_get_handler (const gchar *fname)
 
 	return ft;
 }
-
