@@ -5,10 +5,12 @@
  * Authors:
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
- * Copyright (C) 2003,2006  LUGFI
+ * Copyright (C) 2003,2006  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,23 +24,27 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef _FILE_MANAGER_H_
 #define _FILE_MANAGER_H_ 1
 
 #include <gtk/gtk.h>
-#include "schematic.h"
+#include <string.h>
 
-/* Oregano Files */
+#include "schematic.h"
 #include "load-schematic.h"
 #include "save-schematic.h"
 
-#define FILE_TYPE(a,b,c,d) {a, b, c, d}
+#define FILE_TYPE(a, b, c, d)                                                                      \
+	{                                                                                              \
+		a, b, c, d                                                                                 \
+	}
 
-typedef struct _file_manager_ext_ {
+typedef struct _file_manager_ext_
+{
 	gchar *extension;
 	gchar *description;
 	int (*load_func)(Schematic *schematic, const gchar *filename, GError **error);
@@ -48,4 +54,3 @@ typedef struct _file_manager_ext_ {
 FileType *file_manager_get_handler (const gchar *fname);
 
 #endif
-
