@@ -6,11 +6,15 @@
  *  Richard Hult <rhult@hem.passagen.se>
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
+ *  Bernhard Schuster <bernhard@ahoi.io>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
  * Copyright (C) 1999-2001  Richard Hult
  * Copyright (C) 2003,2004  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
+ * Copyright (C) 2013-2014  Bernhard Schuster
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -25,22 +29,24 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
+
 #ifndef __PART_H
 #define __PART_H
 
-#include <gnome.h>
-#include "sheet-pos.h"
+#include <gtk/gtk.h>
+
+#include "coords.h"
 #include "clipboard.h"
 #include "load-common.h"
 
-#define TYPE_PART			 (part_get_type())
-#define PART(obj)			 (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PART, Part))
-#define PART_CLASS(klass)	 (G_TYPE_CHECK_CLASS_CAST((klass), TYPE_PART, PartClass))
-#define IS_PART(obj)		 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PART))
-#define IS_PART_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS((klass), TYPE_PART, PartClass))
+#define TYPE_PART (part_get_type ())
+#define PART(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PART, Part))
+#define PART_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PART, PartClass))
+#define IS_PART(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PART))
+#define IS_PART_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS ((klass), TYPE_PART, PartClass))
 
 typedef struct _Part Part;
 typedef struct _PartClass PartClass;
@@ -49,18 +55,19 @@ typedef struct _PartPriv PartPriv;
 
 #include "item-data.h"
 
-struct _Pin {
-	SheetPos offset;
+struct _Pin
+{
+	Coords offset;
 	guint pin_nr;
-	gint node_nr; /* Numero de nodo en la netlist */
+	gint node_nr; // Node number into the netlist
 	Part *part;
 };
 
 #define PIN(x) ((Pin *)(x))
 
-struct _Part {
+struct _Part
+{
 	ItemData parent;
-
 	PartPriv *priv;
 };
 
@@ -68,20 +75,20 @@ struct _PartClass
 {
 	ItemDataClass parent_class;
 
-	void (*changed) ();
+	void (*changed)();
 };
 
-GType  part_get_type (void);
-Part  *part_new (void);
-Part  *part_new_from_library_part (LibraryPart *library_part);
-int	   part_get_num_pins (Part *part);
-Pin	  *part_get_pins (Part *part);
-int	   part_set_pins (Part *part, GSList *connections);
-int	   part_get_rotation (Part *part);
+GType part_get_type (void);
+Part *part_new ();
+Part *part_new_from_library_part (LibraryPart *library_part);
+gint part_get_num_pins (Part *part);
+Pin *part_get_pins (Part *part);
+gboolean part_set_pins (Part *part, GSList *connections);
+gboolean part_get_rotation (Part *part);
 IDFlip part_get_flip (Part *part);
-void   part_labels_rotate (Part *part, int rotation);
-
-char   *part_get_property (Part *part, char *name);
+void part_labels_rotate (Part *part, int rotation);
+char **part_get_property_ref (Part *part, char *name);
+char *part_get_property (Part *part, char *name);
 GSList *part_get_properties (Part *part);
 GSList *part_get_labels (Part *part);
 
