@@ -6,11 +6,15 @@
  *  Richard Hult <rhult@hem.passagen.se>
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
+ *  Guido Trentalancia <guido@trentalancia.com>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2006  LUGFI
+ * Copyright (C) 2003,2006  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
+ * Copyright (C) 2017       Guido Trentalancia
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -25,56 +29,77 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
+
+#include <string.h>
 #include <gtk/gtk.h>
+
+#include "debug.h"
 #include "oregano-utils.h"
 
-double
-oregano_strtod (const gchar *str, const gchar unit)
+gdouble oregano_strtod (const gchar *str, const gchar *unit)
 {
-	double ret;
+	gboolean unit_does_not_match = FALSE;
+	gdouble ret;
 	gchar *endptr, *c;
+	size_t unit_length = 0;
+
+	if (unit)
+		unit_length = strlen (unit);
 
 	if (!str)
 		return 0.0;
 
-	ret = g_strtod (str, &endptr);
+	ret = g_ascii_strtod (str, &endptr);
+
 	for (c = endptr; *c; c++) {
 		switch (*c) {
 		case 'T':
 			ret *= 1e12;
-			return ret;
+			break;
 		case 'G':
 			ret *= 1e9;
-			return ret;
+			break;
 		case 'M':
 			ret *= 1e6;
-			return ret;
+			break;
 		case 'k':
 			ret *= 1e3;
-			return ret;
+			break;
 		case 'm':
 			ret *= 1e-3;
-			return ret;
+			break;
 		case 'u':
 			ret *= 1e-6;
-			return ret;
+			break;
 		case 'n':
 			ret *= 1e-9;
-			return ret;
+			break;
 		case 'p':
 			ret *= 1e-12;
-			return ret;
+			break;
 		case 'f':
 			ret *= 1e-15;
-			return ret;
+			break;
+		case ' ':
+			break;
 		default:
-			if (*c == unit)
-				return ret;
+			if (c) {
+				if (!g_ascii_strncasecmp (c, unit, unit_length)) {
+					return ret;
+				} else {
+					unit_does_not_match = TRUE;
+					break;
+				}
+			}
 			break;
 		}
 	}
+
+	if (unit_does_not_match)
+		g_printf ("Unexpected unit of measurement\n");	
+
 	return ret;
 }
