@@ -6,11 +6,13 @@
  *  Richard Hult <rhult@hem.passagen.se>
  *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
  *  Andres de Barbara <adebarbara@fi.uba.ar>
+ *  Marc Lorber <lorber.marc@wanadoo.fr>
  *
- * Web page: http://arrakis.lug.fi.uba.ar/
+ * Web page: https://ahoi.io/project/oregano
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2004  Ricardo Markiewicz
+ * Copyright (C) 2009-2012  Marc Lorber
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,17 +26,18 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
+
 #ifndef __PART_BROWSER_H
 #define __PART_BROWSER_H
 
-#include <gnome.h>
 #include <gtk/gtk.h>
+
 #include "schematic.h"
 
-void part_browser_toggle_show (SchematicView *schematic_view);
+void part_browser_toggle_visibility (SchematicView *schematic_view);
 GtkWidget *part_browser_create (SchematicView *schematic_view);
 void part_browser_dnd (GtkSelectionData *selection_data, gint x, gint y);
 void part_browser_place_selected_part (Schematic *sm);
